@@ -104,6 +104,34 @@ class HastexoXBlock(XBlock,
         scope=Scope.settings,
         help="Display the terminal window in read-only mode"
     )
+    progress_check_label = String(
+        default='Check Progress',
+        scope=Scope.settings,
+        help="Set the progress check button label. "
+             "For example: \"Submit Answer\" or \"Check Progress\"(Default)."
+    )
+    show_feedback = Boolean(
+        default=True,
+        scope=Scope.settings,
+        help="On progress check, show feedback on how many tasks out of total "
+             "are completed."
+    )
+    show_hints_on_error = Boolean(
+        default=True,
+        scope=Scope.settings,
+        help="On progress check failure, display the tests' standard error "
+             "streams as hints. When 'show_feedback' is set to False, hints "
+             "will never be displayed and setting this to True will have no "
+             "effect."
+    )
+    progress_check_result_heading = String(
+        default='Progress check result',
+        scope=Scope.settings,
+        help="Message to display on progress check result window. This could "
+             "be set to \"Answer Submitted\" for example, when choosing to "
+             "not display hints and feedback. Default is \"Progress check "
+             "result\"."
+    )
 
     # Set via XML
     hook_events = Dict(
@@ -162,6 +190,10 @@ class HastexoXBlock(XBlock,
 
     editable_fields = (
         'display_name',
+        'progress_check_label',
+        'progress_check_result_heading',
+        'show_feedback',
+        'show_hints_on_error',
         'weight',
         'stack_template_path',
         'hook_script',
@@ -343,12 +375,19 @@ class HastexoXBlock(XBlock,
             if self.providers:
                 for provider in self.providers:
                     provider_node = etree.SubElement(root, 'provider')
-                    provider_template = provider.get("template", None)
-                    if provider_template in (None, "None"):
-                        provider.pop("template")
-                    provider_environment = provider.get("environment", None)
-                    if provider_environment in (None, "None"):
-                        provider.pop("environment")
+                    # Not having a 'template' or an 'environment' defined for
+                    # a provider is a valid option.
+                    # Only try to remove these when defined but values are
+                    # None or "None" to avoid breaking the export.
+                    if 'template' in provider:
+                        provider_template = provider.get("template", None)
+                        if provider_template in (None, "None"):
+                            provider.pop("template")
+                    if 'environment' in provider:
+                        provider_environment = provider.get("environment",
+                                                            None)
+                        if provider_environment in (None, "None"):
+                            provider.pop("environment")
                     provider_capacity = provider.get("capacity", None)
                     if provider_capacity in (None, "None", ""):
                         # capacity should not be undefined
@@ -371,6 +410,11 @@ class HastexoXBlock(XBlock,
         node.set("filename", filename)
         node.set('xblock-family', self.entry_point)
         node.set('display_name', self.display_name)
+        node.set('progress_check_label', self.progress_check_label)
+        node.set('show_hints_on_error', str(self.show_hints_on_error))
+        node.set('show_feedback', str(self.show_feedback))
+        node.set('progress_check_result_heading',
+                 self.progress_check_result_heading)
         node.set('weight', str(self.weight))
         node.set('stack_user_name', self.stack_user_name)
         node.set('stack_protocol', self.stack_protocol)
@@ -519,7 +563,11 @@ class HastexoXBlock(XBlock,
             "font_name": settings.get("terminal_font_name"),
             "font_size": settings.get("terminal_font_size"),
             "instructions_layout": settings.get("instructions_layout"),
-            "read_only": self.read_only
+            "read_only": self.read_only,
+            "progress_check_label": self.progress_check_label,
+            "show_hints_on_error": self.show_hints_on_error,
+            "show_feedback": self.show_feedback,
+            "progress_check_result_heading": self.progress_check_result_heading
         })
 
         return frag
