@@ -26,6 +26,7 @@ function HastexoXBlock(runtime, element, configuration) {
         /* Display progress check button, if there are tests. */
         if (configuration.has_tests) {
             var button = $(element).find('.buttons .check');
+            button.attr("value", configuration.progress_check_label);
             button.show();
             button.on('click', get_check_status);
         }
@@ -541,6 +542,7 @@ function HastexoXBlock(runtime, element, configuration) {
                 var dialog;
                 if (check.status == 'CHECK_PROGRESS_COMPLETE') {
                     dialog = $('#check_complete');
+                    dialog.find('.check_result_heading').html(configuration.progress_check_result_heading);
                     dialog.find('.check_pass').html(data.pass);
                     dialog.find('.check_total').html(data.total);
                     dialog.find('input.ok').one('click', function() {
@@ -548,14 +550,20 @@ function HastexoXBlock(runtime, element, configuration) {
                     });
                     var hints_title = dialog.find('.hints_title').hide();
                     var hints = dialog.find('.hints').empty().hide();
-                    if (data.errors.length > 0) {
-                        $.each(data.errors, function(i, error) {
-                            var pre = $('<pre>', {text: error});
-                            var li = $('<li>').append(pre);
-                            hints.append(li);
-                        });
-                        hints_title.show();
-                        hints.show();
+                    if (configuration.show_feedback) {
+                        if (configuration.show_hints_on_error) {
+                            if (data.errors.length > 0) {
+                                $.each(data.errors, function(i, error) {
+                                    var pre = $('<pre>', {text: error});
+                                    var li = $('<li>').append(pre);
+                                    hints.append(li);
+                                });
+                                hints_title.show();
+                                hints.show();
+                            }
+                        }
+                    } else {
+                        dialog.find('.check_result_message').hide()
                     }
                     dialog.dialog(dialog_container);
                 } else if (check.status == 'CHECK_PROGRESS_PENDING') {
